require "kitnahua/version"

module Kitnahua
  class Kitnahua

  	attr_accessor :projects

  	def initialize
  	  @db_yml_path = ENV['HOME'] + "/.kitnahua.yml"

  	  # Create file if does not exist.
  	  create_db_file if !File.exists?(@db_yml_path)

  	  load_projects
  	end

    def parse_and_execute_args(argv)

      if argv[0] == nil
      	show_status
      elsif argv[0] == "--reset"
      	reset_db_file
      elsif argv[0] == "--show"
      	show_db_file
	  elsif argv[0] == "--count"
      	show_projects_count
      elsif argv[0] == "--create"
      	create_project(argv[1])
      elsif
      	project = argv[0].to_s.strip
      end

    end

    private

    def create_project(name)
      
      # Return if no name was passed.
      if name == nil 
      	puts "Please provide a project name!" 
      	return 
      end

      # Return if project name is more than 25 chars.
      if name.length > 25
      	puts "Project name cannot be more than 25 chars!" 
      	return 
      end

      # Return if project with passed name already exists
      if @projects[name] != nil 
      	puts "Project with that name already exists!" 
      	return 
      end

      @projects[name] = []
      write_projects_to_db

      puts "Created project '#{name}'."
    end

    def load_projects
      File.open(@db_yml_path,'r') do |f|
      	@projects = YAML.load(f)["projects"]
      end
    end

    def create_db_file
      everything = { "projects" => {} }
      File.open(@db_yml_path,'w') do |f|
      	f.puts everything.to_yaml
      	puts "Created db file #{@db_yml_path} "
      end
    end

    def reset_db_file
      File.delete(@db_yml_path)
      puts "Deleted db file #{@db_yml_path}"
      create_db_file
    end

    def show_db_file
      File.open(@db_yml_path,'r') do |f|
      	puts YAML.load(f).to_yaml
      end
    end

    def show_projects_count
      puts @projects.count
    end

    def write_projects_to_db
      everything = { "projects" => @projects }
      File::open(@db_yml_path,'w') do |f|
	    f.write(everything.to_yaml)
	  end
    end

    def show_status
      puts "TODO: Show status summary of each prohect"
    end

  end
end
